@@ -1,10 +1,10 @@
 ﻿# "This is a template and example of configuration file for Sim::OPT.
 
 $mypath = "/home/luca/tryarea" ;# path of the directory in which you are going to work
-@sweeps = ( [ [ 1 ] ] );
+#@sweeps = ( [ [ 1, 2 ] ] );
 #@sweeps = ( [ [ 1, 2, 3, 4 ] ] );
 #@sweeps = ( [ [ 1, 2, 3], [2, 3, 4] , [ 3, 4, 5], [4, 5, 6 ] ] );
-#@sweeps = ( [ [ 1, 2, 3, 4, 5, 6, 7, 8 ] ] );
+@sweeps = ( [ [ 1, 2, 3, 4, 5, 6, 7 ] ] );
 # OR: ( [ [1, 2], [2, 3] ] ); # OR: @sweeps = ( [ [1, 2, 3, 4], [3, 4, 5, 1], [5, 1, 2, 3] ], [ [1, 2], [2, 3] ] ); # OR: @sweeps = ( [ [1, 2, 3, 4], [3, 4, 5, 1], [5, 1, 2, 3] ] );
 # DESCRIPTION OF A (MAYBE OVERLAPPING) COORDINATE BLOCK DESCENT. # THE NUMBERS ARE THE VARIABLE NUMBERS.
 # MORE THAN ONE SEARCH MAY BE LISTED. # EACH BLOCK SEARCH IS DESCRIBED AS A SEQUENCE OF LIST VARIABLES.
@@ -13,28 +13,28 @@ $mypath = "/home/luca/tryarea" ;# path of the directory in which you are going t
 # @sweeps IS NOT OVERRIDDEN ON THE BASIS OF WHAT IS SPECIFIED IN @chanceseed AND @caseseed. 
 # IT HAS TO BE UNSPECIFIED IF THE SEARCH STRUCTURE HAS TO BE CALCULATE BY THE PROGRAM. @sweepseed MAY BE SPECIFIED IN ITS PLACE.
 
-@varinumbers = ( { 1 => 3 } );
+#@varinumbers = ( { 1 => 2, 2 => 2 } );
 #@varinumbers = ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 #@varinumbers = ( { 1 => 3, 2 => 3, 3 => 3, 4 => 3, 5 => 3, 6 => 3 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
-#@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 9, 7 => 2, 8 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
+@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 8, 7 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' } ); # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' }, { 1 => '3', 2 => '3', 3 => '3' } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE NUMBER OF ITERATIONS FOR EACH VARIABLES ARE SPECIFIED.
 
-@mediumiters = ( { 1 => 2 } );
+#@mediumiters = ( { 1 => 1, 2 => 2 } );
 #@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2 } );
 #@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 2 } );
-#@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 1, 6 => 5, 7 => 1 , 8 => 1 } );
-#mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 1, 6 => 5, 7 => 1 , 8 => 1 } ); # OR: @mediumiters = ( { 1 => 2, 2 => 2, 3 => 2 } );
+@mediumiters = ( { 1 => 1, 2 => 1, 3 => 1, 4 => 1, 5 => 1, 6 => 4, 7 => 1  } );
+#@mediumiters = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 1, 6 => 4, 7 => 1 , 8 => 1 } ); # OR: @mediumiters = ( { 1 => 2, 2 => 2, 3 => 2 } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 # IF LEFT UNSPECIFIED IT DEFAULTS TO THE MIDDLE ITERATION FOR EACH VARIABLE.  # IF LEFT UNSPECIFIED IT DEFAULTS TO THE CENTRAL VALUE FOR EACH GIVEN RANGE. 
 
-$file = "testmodish_ep";  # the root model directory.
+$file = "testmodish2_ep";  # the root model directory.
 
 %dowhat = ( # This variables tells to the program what to do.
 morph => "y", # create cases for simulation?
-simulate => "y", # simulate AND retrieve? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
-retrieve => "y",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
-report => "y",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
+simulate => "n", # simulate AND retrieve? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
+retrieve => "n",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
+report => "n",  # retrieve data? THIS MUST BE "y" TO PERFORM BLOCK SEARCH.
 descend => "n", # descend into results? THIS MUST BE "y" FOR BLOCK SEARCH.
 eraseres => "n", # erase .res and .fl files as they are created or leave them as traces?
 substitutenames => "n", # substitute names (convert) in non-filtered reports? (UNTESTED SINCE EARLY VERSIONS.)
@@ -45,19 +45,17 @@ actonexisting_models => { 1 => "y" },
 simtools => { 1 => "energyplus", 
 #2 => "esp-r" 
 },
-#reptools => { 1 => "esp-r" },
 ); # 11) THIS MUST BE "y" TO PERFORM BLOCK SEARCH. It checks if it is possible to launch a block search, and if it is does it.
 
-$fileconfig = "boxform.cfg"; # name of the configuration file of the model, which will reside in the "./cfg/" directory in your model's directory.
+$fileconfig = "newbox21.idf"; # name of the configuration file of the model, which will reside in the "./cfg/" directory in your model's directory.
 
 $simnetwork = "n"; # is there a mass/flow network? This information regards the simulation settings.
 $exeonfiles = "y";
 $preventsim = "n";
 
 $simtitles{1} = [ # TRANSFORMATIONS TO BE DONE TO AN .idf FILE BEFORE LAUNCHING A SIMULATION
-[ "feb01-feb08", "1 2", "8 2", "20", "1", "milan.epw", "/ep", "boxform_jwh2.idf", "_feb", "/Output", ".idf", "Table.html", [ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], [ "4;   !- Time Step in Hour", "1;   !- Time Step in Hour" ], [ "1, 1,   !- Begin Month", "2, 1,   !- Begin Month" ], [ "12,31,   !- End Month", " 2, 7,   !- End Month" ] ], 
-[ "jul01-jul08", "1 7", "8 7", "20", "1", "milan.epw", "/ep", "boxform_jwh2.idf", "_jul", "/Output", ".idf", "Table.html", [ "FullInteriorAndExterior", "FullInteriorAndExteriorWithReflections" ], [ "4;   !- Time Step in Hour", "1;   !- Time Step in Hour" ], [ "1, 1,   !- Begin Month", "7, 1,   !- Begin Month" ], [ "12,31,   !- End Month", " 7, 7,   !- End Month" ] ],
-];
+[ "epannual", "1 1", "12 31", "20", "1", "milan.epw", "/ep", "newbox21.idf", "", "", ".idf", "Table.html" ], 
+]; # [ "name", "begin_date", "end_date", "warmup_days", "timestep", "climatefile", "epfile_directory", "epfile_name", "distinctive_part_of_name", "output_directory", ".config_file_type", ".output_file_type" ]
 
 #$vals{1}{skipsim} = " ( ( $to =~ /_1-2/ ) or ( $to =~ /_2-2/ ) or ( $to =~ /_3-2/ ) or ( $to =~ /_4-2/ ) or ( $to =~ /_5-2/ ) or ( $to =~ /_6-2/ ) ) ";
 #$vals{1}{skipsim} = " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-3/ ) or ( \$to =~ /_6-5/ ) ) ";
@@ -206,26 +204,141 @@ $reportdata{1} = # THERE IS A POINT-TO POINT CORRESPONDENCE TO THE ITEMS IN @ret
 
 ######################### PARAMETER 1. #############################
 
-$vals{1}{1}{applytype} = [ [ "genchange", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+
+$vals{1}{1}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
 # "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
-$vals{1}{1}{general_variables} = 
+$vals{1}{1}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
+[ #BRACKET FOR GROUP
+[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
+[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
+[ # BRACKET DELIMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
+[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
+"/ep/newbox21.idf", # FILE TO BE MODIFIED.
+#[ [ 19 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
+[ [ 19, 20, 21, 22, 34, 35, 66, 67, 79, 82, 95, 96 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
+[ 2 ], [ 0, -1.5 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+]
+]
+]
+];
+
+
+$vals{1}{2}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
+# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
+$vals{1}{2}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
+[ #BRACKET FOR GROUP
+[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
+[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
+[ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
+[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
+"/ep/newbox21.idf", # FILE TO BE MODIFIED.
+[ [ 199, 200, 201, 202, 214, 215, 229, 230, 231, 232, 246, 247, 259, 262, 275, 276 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
+[ 2 ], [ 0, -1.5 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+]
+]
+]
+];
+
+$vals{1}{3}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
+# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
+$vals{1}{3}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
+[ #BRACKET FOR GROUP
+[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
+[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
+[ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
+[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
+"/ep/newbox21.idf", # FILE TO BE MODIFIED.
+[ [ 289, 290, 291, 292, 304, 305, 336, 337, 349, 352, 365, 366 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
+[ 2 ], [ 0, -1.5 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+]
+]
+]
+];
+
+$vals{1}{4}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
+# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
+$vals{1}{4}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
+[ #BRACKET FOR GROUP
+[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
+[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
+[ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
+[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
+"/ep/newbox21.idf", # FILE TO BE MODIFIED.
+[ [ 379, 380, 381, 382, 394, 395, 426, 427, 439, 442, 455, 456 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
+[ 2 ], [ 0, -1.5 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+]
+]
+]
+];
+
+$vals{1}{5}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
+# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
+$vals{1}{5}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
+[ #BRACKET FOR GROUP
+[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
+[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
+[ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
+[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
+"/ep/newbox21.idf", # FILE TO BE MODIFIED.
+[ [ 109, 112, 124, 127, 139, 142, 154, 157, 169, 170, 171, 172 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
+[ 3 ], [ 0, 4 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+]
+]
+]
+];
+
+
+$vals{1}{6}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
+# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
+$vals{1}{6}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
+[ #BRACKET FOR GROUP
+[ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
+[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
+[ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
+[ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
+"/ep/newbox21.idf", # FILE TO BE MODIFIED.
+[ [ 19, 20, 21, 22, 34, 35, 36, 37, 49, 50, 51, 52, 64, 65, 66, 67, 79, 80, 81, 82, 94, 95, 96, 97,
+109, 110, 111, 112, 124, 125, 126, 127, 139, 140, 141, 142, 154, 155, 156, 157, 169, 170, 171, 172, 184, 185, 186, 187,
+199, 200, 201, 202, 214, 215, 216, 217, 229, 230, 231, 232, 244, 245, 246, 247, 259, 260, 261, 262, 274, 275, 276, 277,
+289, 290, 291, 292, 304, 305, 306, 307, 319, 320, 321, 322, 334, 335, 336, 337, 349, 350, 351, 352, 364, 365, 366, 367,
+379, 380, 381, 382, 394, 395, 396, 397, 409, 410, 411, 412, 424, 425, 426, 427, 439, 440, 441, 442, 454, 455, 456, 457,
+490, 491, 492, 493, 506, 507, 508, 509, 522, 523, 524, 525, 538, 539, 540, 541, 554, 555, 556, 557, 570, 571, 572, 573 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
+[ 1, 2 ], [ -135, 180 ], [  ], "rotation2d" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
+]
+]
+]
+];
+
+$vals{1}{7}{applytype} = [ [ "genchange", "newbox21.idf", "newbox21.idf", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
+# the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
+# "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
+# "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
+$vals{1}{7}{general_variables} = 
 [
 "y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
 "n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
 ];
-$vals{1}{1}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
+$vals{1}{7}{genchange} =  #THIS MEANS: CHANGE OF "generic" TYPE, WHICH ARE TRASFORMATIONS OF SPECIFIED PARTS OF TEXT FILES.
 [ #BRACKET FOR GROUP
 [ #BRACKET FOLLOWING THE @applype BRACKETS. EACH BRACKET IS A SEQUENCE OF OPEARATION TO BE MADE IN PARALLEL. HERE THERE IS JUST ONE SEQUENCE.
-[ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ], # THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
+[  ], # EXAMPLE: [ "/relative_constrainfile1_path", "/relative_constrainfile2_path" ] THESE CAN BE ABSENT. IN THAT CASE, PUT: [] (EMPTY BARACKETS. THESE ARE ONE OR MORE FILES IN WHICH RULES FOR PROPAGATION OF CONSTRAINTS ARE WRITTEN. THEY ARE READ_AND_PROPAGATED ONE BY ONE, SEQUENTIALLY. # GIVE SEMI-LOCAL PATH WITHOUT THE DOTS (EXAMPLE: "/cfg/file". 
 [ # BRACKET DELEMITING THE GROUP OF OPERATIONS FOR THIS GROUP OF ACTIONS.
 [ # BKACKET DELIMITING THIS GROUP OF ACTIONS. THERE IS ONLY ONE GROUP OF ACTIONS IN THIS GROUP OF OPERATIONS.
-"/ep/boxform_jwh2.idf", # FILE TO ACTED ON.
-[ 365, 3, 0.5, "first_a", "+" ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ line_number_to_change, item_number_to_change, half_variation_range, "variable'snickname", "+" ]; WHERE "+" MEANS: LINEAR INTERPOLATION.
-[ 365, 2, 0.4, "first_b", "+" ], # SECOND CHANGE TO BE MADE. 
-[ 366, 1, [ -0.3, 0.3 ], "second_a", "+" ], # THIRD CHANGE TO BE MADE. THIS MEANS: [ line_number_to_change, item_number_to_change, [ min_variation, max_variation], "variable'snickname", "+" ]; WHERE "+" MEANS: LINEAR INTERPOLATION.
-[ 367, 2, [ -0.7, 0.7 ], "third_a", "+" ], # FOURTH CHANGE TO BE MADE. 
+"/ep/newbox21.idf", # FILE TO BE MODIFIED.
+[ [ 936 ], # FIRST CHANGE TO BE MADE. THIS MEANS: [ [line_number_to_change1, line_number_to_change2, ... line_number_to_changen], 
+[ 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13 ], [ 0, 0.6 ], [  ], "linear" ], # [ line_item_number_to_change1, line_item_number_to_change2, ... line_item_number_to_change3], [ low_variation, high_variation ], [ change's_nickname_1, ... change's_nickname_n ], change_type:"linear"_or_"rotation2d" ]; 
 ]
 ]
 ]
