@@ -17,12 +17,12 @@ $mypath = "/home/luca/tryarea" ;# path of the directory in which you are going t
 # @sweeps IS NOT OVERRIDDEN ON THE BASIS OF WHAT IS SPECIFIED IN @chanceseed AND @caseseed. 
 # IT HAS TO BE UNSPECIFIED IF THE SEARCH STRUCTURE HAS TO BE CALCULATE BY THE PROGRAM. @sweepseed MAY BE SPECIFIED IN ITS PLACE.
 
-@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 8, 7 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
+@varinumbers = ( { 1 => 2, 2 => 2, 3 => 2, 4 => 2, 5 => 2, 6 => 2, 7 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 #@varinumbers = ( { 1 => 2 } ); #THIS IS THE DEFAULT. THESE VALUES CAN BE OVERRIDDEN BELOW, IN THE PARAMETERS' SPECIFICATIONS
 # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' } ); # OR: @varinumbers = ( { 1 => '3', 2 => '3', 3 => '3', 4 => '3', 5 => '3' }, { 1 => '3', 2 => '3', 3 => '3' } );
 # IN THIS ARRAY OF HASHES (DICTIONARIES) THE NUMBER OF ITERATIONS FOR EACH VARIABLES ARE SPECIFIED.
 
-@mediumiters = ( { 1 => 1, 2 => 1, 3 => 1, 4 => 1, 5 => 1, 6 => 5, 7 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
+@mediumiters = ( { 1 => 1, 2 => 1, 3 => 1, 4 => 1, 5 => 1, 6 => 1, 7 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 #@mediumiters = ( { 1 => 1 } ); # IN THIS ARRAY OF HASHES (DICTIONARIES) THE BASE ITERATION FOR EACH VARIABLES ARE SPECIFIED. 
 # IF LEFT UNSPECIFIED IT DEFAULTS TO THE MIDDLE ITERATION FOR EACH VARIABLE.  # IF LEFT UNSPECIFIED IT DEFAULTS TO THE CENTRAL VALUE FOR EACH GIVEN RANGE. 
 
@@ -504,11 +504,6 @@ $vals{1}{1}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ]
 # the following morphing operations are available: "translate", "rotate", "rotatez", "surface_translate", "shift_vertices", 
 # "rotate_surface", "warping", "construction_reassign", "change_thickness", "obs_modify", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "genchange", "translate_vertices", "change_climate"
-$vals{1}{1}{general_variables} = 
-[
-"y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
-"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
-];
 $vals{1}{1}{obs_modify} = 
 [   
 [ 
@@ -524,11 +519,6 @@ $vals{1}{2}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ]
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "genchange"
-$vals{1}{2}{general_variables} = 
-[
-"y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
-"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
-];
 $vals{1}{2}{obs_modify} = 
 [   
 [ 
@@ -552,11 +542,6 @@ $vals{1}{3}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ]
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "genchange"
-$vals{1}{3}{general_variables} = 
-[
-"y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
-"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
-];
 $vals{1}{3}{obs_modify} = 
 [   
 [ 
@@ -580,11 +565,6 @@ $vals{1}{4}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ]
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "genchange"
-$vals{1}{4}{general_variables} = 
-[
-"y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
-"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
-];
 $vals{1}{4}{obs_modify} = 
 [   
 [ 
@@ -608,11 +588,6 @@ $vals{1}{5}{applytype} = [ [ "obs_modify", "boxform.cfg", "boxform.cfg", "a" ] ]
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "genchange"
-$vals{1}{5}{general_variables} = 
-[
-"y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
-"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
-];
 $vals{1}{5}{obs_modify} = 
 [   
 [ 
@@ -634,33 +609,20 @@ $vals{1}{6}{applytype} = [ [ "rotate", "boxform.cfg", "boxform.cfg", "a" ] ] ; #
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "genchange"
-$vals{1}{6}{general_variables} = 
-[
-"y", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
-"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
-];
 $vals{1}{6}{rotate} = 
 [ 
-[ "y", [ -90, 180 ], "c", "a" ],
+[ "n", [ 0, 90 ], "c", "a" ],
 ];
-#$vals{1}{6}{skipop}  = [ [ " ( ( \$to =~ /_1-2/ ) or ( \$to =~ /_2-2/ ) or ( \$to =~ /_3-2/ ) or ( \$to =~ /_4-2/ ) or ( \$to =~ /_5-2/ ) or ( \$to =~ /_6-2/ ) ) " ] ];
-#$vals{1}{6}{skipop} = [ [ " ( ( $to =~ /_6-5/ ) ) " ] ];
 # [ # rotate obstructions? "y" o "n", # swing of rotation (HALF SWING, SWING MEASURED ON ONE SIDE WITH REGARDS TO THE MIDDLE) 
 # update radiation calculation with the "ish" module?  "b" for yes and "c" for no, continue, # vertex around which to rotate ]
 ##### @applytype111 = (["rotation", "file_name", "target_file_name", "zone_letter"]);
 
-
 ######################### PARAMETER 7. #############################
 
 $vals{1}{7}{applytype} = [ [ "change_groundreflectance", "boxform.cfg", "boxform.cfg", "a" ] ] ; #  @applytype(n) = (["type_of_change", "your_test_file", "file_name_to_which_the_former_will_be_copied_to", "zone_letter"]), 
 # the following morphing operations are available: "translation", "rotation", "rotationz", "surface_translation", "vertices_shift", 
 # "surface_rotation", "warping", "construction_reassignment", "thickness_change", "obs_modification", "generic_change", "vary_controls", “vary_net”, 
 # "change_groundreflectance", "genchange"
-$vals{1}{7}{general_variables} = 
-[
-"n", # $generate(n) eq "n" # (if the models deriving from this runs will not be generating new models) or y (if they will be generating new models).
-"n" #if $sequencer eq "y", or "last" (of a sequence) iteration between non-continuous cases wanted.  The first gets appended to the middle(s) and to he last. Otherwise, "n".
-];
 $vals{1}{7}{change_groundreflectance} =  
 [ 
 [ 0.20, [ 0, 0.60 ] ] # [ base value, [ low_change, high_change ] ]; OR: [ base value, half-range ];
